@@ -15,13 +15,14 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-""" Logging utilities. """
+"""Logging utilities."""
 
 import logging
 
 import click
 import click_log
-from cloup import GroupedOption
+
+from . import Choice, Option
 
 LOG_LEVELS = {
     name: value
@@ -57,8 +58,7 @@ class WrappedLogger:
 
     def reset(self):
         """Forces the logger level to reset at the end of each CLI execution, as it
-        might pollute the logger state between multiple test calls.
-        """
+        might pollute the logger state between multiple test calls."""
         self.wrapped_logger.setLevel(logging.NOTSET)
 
 
@@ -71,11 +71,11 @@ def verbosity_option(
     *names,
     default="INFO",
     metavar="LEVEL",
-    type=click.Choice(LOG_LEVELS, case_sensitive=False),
+    type=Choice(LOG_LEVELS, case_sensitive=False),
     expose_value=False,
     help=f"Either {', '.join(LOG_LEVELS)}.",
     is_eager=True,
-    cls=GroupedOption,
+    cls=Option,
     **kwargs,
 ):
     """Adds a ``--verbosity``/``-v`` option.
