@@ -15,46 +15,44 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-"""Test defaults of our custom commands, as well as their customizations and attached options, and how they interact with each others."""
+"""Test defaults of our custom commands, as well as their customizations and attached
+options, and how they interact with each others."""
 
 import re
 import sys
 from textwrap import dedent
 
 import click
+import cloup
 import pytest
-from click import option as click_option
-from cloup import command as cloup_command
-from cloup import option as cloup_option
-from cloup import option_group
 
-from ..commands import command as click_extra_command
-from ..commands import group, timer_option
+from .. import command, echo, group, option, option_group, timer_option
+from .conftest import default_options_uncolored_help
 
 
 @group(version="2021.10.08")
 def default_group():
-    click.echo("It works!")
+    echo("It works!")
 
 
 @default_group.command()
 def default_subcommand():
-    click.echo("Run default subcommand...")
+    echo("Run default subcommand...")
 
 
-@click_extra_command()
+@command()
 def click_extra_subcommand():
-    click.echo("Run click-extra subcommand...")
+    echo("Run click-extra subcommand...")
 
 
-@cloup_command()
+@cloup.command()
 def cloup_subcommand():
-    click.echo("Run cloup subcommand...")
+    echo("Run cloup subcommand...")
 
 
-@click.command()
+@click.command
 def click_subcommand():
-    click.echo("Run click subcommand...")
+    echo("Run click subcommand...")
 
 
 default_group.section(
@@ -62,27 +60,11 @@ default_group.section(
 )
 
 
-default_options_help_screen = (
-    r"  --time / --no-time        Measure and print elapsed execution time.  \[default:\n"
-    r"                            no-time\]\n"
-    r"  --color, --ansi / --no-color, --no-ansi\n"
-    r"                            Strip out all colors and all ANSI codes from output.\n"
-    r"                            \[default: color\]\n"
-    r"  -C, --config CONFIG_PATH  Location of the configuration file. Supports both\n"
-    r"                            local path and remote URL.  \[default:( \S+)?\n"
-    r"(                            \S+\n)*"
-    r"                            \S+config.{toml,yaml,yml,json}\]\n"
-    r"  -v, --verbosity LEVEL     Either CRITICAL, ERROR, WARNING, INFO, DEBUG.\n"
-    r"                            \[default: INFO\]\n"
-    r"  --version                 Show the version and exit.\n"
-    r"  -h, --help                Show this message and exit.\n"
-)
-
 help_screen = (
     r"Usage: default-group \[OPTIONS\] COMMAND \[ARGS\]...\n"
     r"\n"
     r"Options:\n"
-    rf"{default_options_help_screen}"
+    rf"{default_options_uncolored_help}"
     r"\n"
     r"Subcommand group:\n"
     r"  click-extra-subcommand\n"
@@ -129,7 +111,8 @@ def test_group_help(invoke, param):
     ("--version", "blah", ("--verbosity", "DEBUG"), ("--config", "random.toml")),
 )
 def test_help_eagerness(invoke, params):
-    # See: https://click.palletsprojects.com/en/8.0.x/advanced/#callback-evaluation-order
+    # See:
+    # https://click.palletsprojects.com/en/8.0.x/advanced/#callback-evaluation-order
     result = invoke(default_group, "--help", params, color=False)
     assert result.exit_code == 0
     assert re.fullmatch(help_screen, result.stdout)
@@ -150,7 +133,7 @@ def test_click_extra_subcommand_help(invoke, cmd_id, param):
             rf"Usage: default-group {cmd_id}-subcommand \[OPTIONS\]\n"
             r"\n"
             r"Options:\n"
-            rf"{default_options_help_screen}"
+            rf"{default_options_uncolored_help}"
         ),
         result.stdout,
     )
@@ -202,10 +185,10 @@ def test_integrated_version_value(invoke):
 
 
 def test_standalone_timer_option(invoke):
-    @click.command()
+    @click.command
     @timer_option()
     def dummy_cli():
-        click.echo("It works!")
+        echo("It works!")
 
     result = invoke(dummy_cli, "--time")
     assert result.exit_code == 0
@@ -242,17 +225,17 @@ def test_option_group_integration(invoke):
     @group()
     @option_group(
         "Group 1",
-        click_option("-a", "--opt1"),
-        cloup_option("-b", "--opt2"),
+        click.option("-a", "--opt1"),
+        option("-b", "--opt2"),
     )
-    @click_option("-c", "--opt3")
-    @cloup_option("-d", "--opt4")
+    @click.option("-c", "--opt3")
+    @option("-d", "--opt4")
     def default_group(opt1, opt2, opt3, opt4):
-        click.echo("It works!")
+        echo("It works!")
 
     @default_group.command()
     def default_command():
-        click.echo("Run command...")
+        echo("Run command...")
 
     result = invoke(default_group, "--help", color=False)
     assert result.exit_code == 0
@@ -267,19 +250,7 @@ def test_option_group_integration(invoke):
             r"Other options:\n"
             r"  -c, --opt3 TEXT\n"
             r"  -d, --opt4 TEXT\n"
-            r"  --time / --no-time        Measure and print elapsed execution time.  \[default:\n"
-            r"                            no-time\]\n"
-            r"  --color, --ansi / --no-color, --no-ansi\n"
-            r"                            Strip out all colors and all ANSI codes from output.\n"
-            r"                            \[default: color\]\n"
-            r"  -C, --config CONFIG_PATH  Location of the configuration file. Supports both\n"
-            r"                            local path and remote URL.  \[default:( \S+)?\n"
-            r"(                            \S+\n)*"
-            r"                            \S+config.{toml,yaml,yml,json}\]\n"
-            r"  -v, --verbosity LEVEL     Either CRITICAL, ERROR, WARNING, INFO, DEBUG.\n"
-            r"                            \[default: INFO\]\n"
-            r"  --version                 Show the version and exit.\n"
-            r"  -h, --help                Show this message and exit.\n"
+            rf"{default_options_uncolored_help}"
             r"\n"
             r"Commands:\n"
             r"  default-command\n"
